==> breeze_update_4.0.01.tar.gz: manage/edit_menu_items.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Completely re-engineered: 12/17/2010	ELL
// Revised: 2/19/2011	ELL
// Fixed bugs with moving items and inserting items when using Internet Explore.  It was working fine in
// Firefox, Opera, Safari and Chrome, but IE processes .innerHTML in a very weird way.  Note that UpdateAll() 
// function is run after moving items for IE only to correct some of the problems with working with id
// attributes to tags once IE processes the .innerHTML.
// Revised: 2/8/2012	ELL
// Added table prefix handling.
// Revised: 3/1/2012	ELL
// Fixed bugs with indents not working properly upon inserting new items.
// 
//

	include ("check_session.php");
		
	$menu = $_REQUEST['menu'];
	if (!isset($menu))
		$menu = $_SESSION['last_menu_edited'];
	else
		$_SESSION['last_menu_edited'] = $menu;
	
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<title>Breeze Website Builder</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link rel="stylesheet" href="manager.css" type="text/css">
<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">

<style type="text/css">
#help_button	{
	top:30px;
	right:20px;
}

.header_row	{
	padding-left:5px;
	padding-right:5px;
}
</style>

<script type="text/javascript" src="js/json2.js"></script>
<script type="text/javascript" src="js/ajax.js"></script>
<script type="text/javascript" src="js/trim.js"></script>
<script type="text/javascript" src="js/escape_url.js"></script>
<script type="text/javascript" src="js/mouse_position.js"></script>
<script type="text/javascript" src="js/edit_menu_items.js"></script>

<script language="javascript" type="text/javascript" >

var update_all = false;
var pages = new Array();
var pages_full = new Array();
var bgclr = "#eeeeee";
var saved = true;

<?php
	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
	$result = $bwb_dbh->query($query);
	$num_results = $result->rowCount();
	$page_name_tmp = "";
	for ($j = 0; $j < $num_results; $j++)
	{
		$row = $result->fetch(PDO::FETCH_ASSOC);
		$page_name = $row["page_name"];
		$page_name_full = $page_name . ".php";
		echo "pages[$j] = '$page_name';\n";
		echo "pages_full[$j] = '$page_name_full';\n";
	}
	echo "var page_cnt = $j;\n";
?>
</script>

</head>

<body>
<div align="center">

<table width="80%"><tr>
<td class="title" align="right">Revise Menu Items</td>
<td align="center" width="35%"><div id="StatusMsg"> </div></td>
<td align="right"><input type="button" name="Back" id="Back" value="Back to Main Menu" onClick="RetunToMainConfirm();"></td>
</tr></table>
	Select a menu to add items to: 
    <select name="selectMenu" id="selectMenu" onChange="javascript:RetrieveMenuItems();">
    <option value="-not selected-">-not selected-</option>
<?php
	$use_default_menu = 0;
	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menus`";
	$result = $bwb_dbh->query($query);
	$use_default_menu = $result->rowCount();
	while($row = $result->fetch(PDO::FETCH_ASSOC))
	{
		$menu_name = $row['menu_name'];
		$description = $row['description'];
		if (($menu_name == $menu) || (($use_default_menu == 2) && ($menu_name == "menu1") && ($menu == "")))
			echo "<option value='$menu_name' selected='selected'>$description</option>\n";
		else
			echo "<option value='$menu_name'>$description</option>\n";
	}
?>
    </select>
	
    <div id="help_button" onClick="OpenHelpWindow();">
    &nbsp;
  	</div>
    
<?php
	if (($use_default_menu == 2) && ($menu == ""))
		$menu_source = "menu1_items";
	elseif (($menu == "-not selected-") || ($menu == ""))
		echo "Please select a menu to edit menu items.";
	else
	{
		$suffix = substr($menu, 4);
		$menu_source  = "menu" . $suffix . "_items";
	}
?>
	<div id="MenuItemsTable">&nbsp;</div>
    
		<input type='hidden' name='nCount' id='nCount'>
        <table width="80%">
		<tr><td colspan="5">&nbsp;</td></tr>
		<tr>
		<td align="center"><input type="button" value="Update All" name="update" id="update" onClick="UpdateAll();"></td>
        <td colspan="3" align="center"><div id="StatusMsg2"> </div></td>
		<td align="right">
          <input type="button" value="Back to Main Menu" name="back" onClick="RetunToMainConfirm();">
		</td>
		</tr>
	</table>

</div>

<div id="delete_confirm">
<table border="0" cellspacing="0" cellpadding="5" align="center">
  <tr>
    <td colspan="2">Are your sure you want to delete the <b><div id="delete_text">&nbsp;</div></b> menu item?</td>
  </tr>
  <tr>
	<td align="center"><input type="button" name="delete" id="delete" value="Yes" onClick="DeleteMenuItem();"></td>
	<td align="center"><input type="button" name="hide_delete" value="No" onClick="HideDelete();">
    <input type="hidden" name="menu_item_to_delete" id="menu_item_to_delete">
    </td>
  </tr>
</table>
</div>

<div id="return_confirm">
<table border="0" cellspacing="0" cellpadding="5" align="center">
  <tr>
    <td colspan="2">Your changes have not been saved. Do you want to save your changes before returning to the main menu?</td>
  </tr>
  <tr>
	<td align="center"><input type="button" name="save" value="Yes" onClick="ReturnToMainMenu(1);"></td>
	<td align="center"><input type="button" name="abort" value="No" onClick="ReturnToMainMenu(0);">
    </td>
  </tr>
</table>
</div>
<?php
	if (isset($menu))
	{
		echo "<script language='javascript' type='text/javascript'>\n";
		echo "   RetrieveMenuItems();\n";
		echo "</script>\n";
	}
?>
</body>
</html>

==> breeze_update_4.5.01.tar.gz: manage/edit_menu_items.php <==
<?php
////////////////////////////////////////////////////////////////////////
// Breeze Website Builder
// Copyright EB Dynamics, Inc., Edward Lemmers, P.E.
// For licensing, see license.txt.
// Completely re-engineered: 12/17/2010	ELL
// Revised: 2/19/2011	ELL
// Fixed bugs with moving items and inserting items when using Internet Explore.  It was working fine in
// Firefox, Opera, Safari and Chrome, but IE processes .innerHTML in a very weird way.  Note that UpdateAll() 
// function is run after moving items for IE only to correct some of the problems with working with id
// attributes to tags once IE processes the .innerHTML.
// Revised: 2/8/2012	ELL
// Added table prefix handling.
// Revised: 3/1/2012	ELL
// Fixed bugs with indents not working properly upon inserting new items.
// Revised: 7/1/2013	ELL
// Implemented popup message class.
// 
//

	include ("check_session.php");
		
	$menu = $_REQUEST['menu'];
	if (!isset($menu))
		$menu = $_SESSION['last_menu_edited'];
	else
		$_SESSION['last_menu_edited'] = $menu;
	
?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
<html>
<head>
<title>Breeze Website Builder</title>
<meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
<link rel="stylesheet" href="manager.css" type="text/css">
<link rel="shortcut icon" href="images/favicon.ico" type="image/x-icon">

<style type="text/css">
#help_button	{
	top:30px;
	right:20px;
}

.header_row	{
	padding-left:5px;
	padding-right:5px;
}
</style>

<script type="text/javascript" src="js/json2.js"></script>
<script type="text/javascript" src="js/ajax.js"></script>
<script type="text/javascript" src="js/trim.js"></script>
<script type="text/javascript" src="js/escape_url.js"></script>
<script type="text/javascript" src="js/mouse_position.js"></script>
<script type="text/javascript" src="js/popup_msg.js"></script>
<script type="text/javascript" src="js/edit_menu_items.js"></script>

<script language="javascript" type="text/javascript" >

var update_all = false;
var pages = new Array();
var pages_full = new Array();
var bgclr = "#eeeeee";
var saved = true;

<?php
	$query = "SELECT page_name FROM " . BWB_TABLE_PREFIX . "page_data ORDER BY page_name";
	$result = $bwb_dbh->query($query);
	$num_results = $result->rowCount();
	$page_name_tmp = "";
	for ($j = 0; $j < $num_results; $j++)
	{
		$row = $result->fetch(PDO::FETCH_ASSOC);
		$page_name = $row["page_name"];
		$page_name_full = $page_name . ".php";
		echo "pages[$j] = '$page_name';\n";
		echo "pages_full[$j] = '$page_name_full';\n";
	}
	echo "var page_cnt = $j;\n";
?>
</script>

</head>

<body>
<div align="center">

<table width="80%"><tr>
<td class="title" align="right">Revise Menu Items</td>
<td align="right"><input type="button" name="Back" id="Back" value="Back to Main Menu" onClick="RetunToMainConfirm();"></td>
</tr></table>
	Select a menu to add items to: 
    <select name="selectMenu" id="selectMenu" onChange="javascript:RetrieveMenuItems();">
    <option value="-not selected-">-not selected-</option>
<?php
	$use_default_menu = 0;
	$query = "SELECT * FROM `" . BWB_TABLE_PREFIX . "menus`";
	$result = $bwb_dbh->query($query);
	$use_default_menu = $result->rowCount();
	while($row = $result->fetch(PDO::FETCH_ASSOC))
	{
		$menu_name = $row['menu_name'];
		$description = $row['description'];
		if (($menu_name == $menu) || (($use_default_menu == 2) && ($menu_name == "menu1") && ($menu == "")))
			echo "<option value='$menu_name' selected='selected'>$description</option>\n";
		else
			echo "<option value='$menu_name'>$description</option>\n";
	}
?>
    </select>
	
    <div id="help_button" onClick="OpenHelpWindow();">
    &nbsp;
  	</div>
    
<?php
	if (($use_default_menu == 2) && ($menu == ""))
		$menu_source = "menu1_items";
	elseif (($menu == "-not selected-") || ($menu == ""))
		echo "Please select a menu to edit menu items.";
	else
	{
		$suffix = substr($menu, 4);
		$menu_source  = "menu" . $suffix . "_items";
	}
?>
	<div id="MenuItemsTable">&nbsp;</div>
    
		<input type='hidden' name='nCount' id='nCount'>
        <table width="80%">
		<tr><td colspan="5">&nbsp;</td></tr>
		<tr>
		<td align="center"><input type="button" value="Update All" name="update" id="update" onClick="UpdateAll();"></td>
		<td align="right">
          <input type="button" value="Back to Main Menu" name="back" onClick="RetunToMainConfirm();">
		</td>
		</tr>
	</table>

</div>

<?php include("lib/popup_msg.html"); ?>

<script language='javascript' type='text/javascript'>
	HidePopupMsg();
<?php
	if (isset($menu))
		echo "      RetrieveMenuItems();\n";
?>
</script>
</body>
</html>
